import games
import search


def check_othello_performance(depth, logfile="", cache=False, function=""):
    game = games.Othello()
    if function == "improved":
        f = game.improved_evaluation_function
    else:
        f = game.evaluation_function
    player1 = search.TreeSearchPlayer(depth, 'B', f, cache=cache)
    player2 = search.RandomPlayer('W')

    state = game.start_state
    turn_player = player1

    while not game.is_terminal_state(state):
        action = turn_player.compute_action(game, state)
        if action is None:
            pass
        else:
            state = game.generate_next_state(state, action)
        turn_player = player2 if turn_player.player == player1.player else player1

    score1 = (state == player1.player).sum()
    score2 = (state == player2.player).sum()

    if len(logfile) > 0:
        with open(logfile, "a") as file:
            file.write("{}, {}, {}, {}\n".format(depth, score1, score2, player1.expanded_nodes))


if __name__ == '__main__':
    for i in range(55):
        check_othello_performance(3, "othello_cached.csv", cache=True)
