import games
import search


def check_othello_performance(depth, logfile="", alphabeta=False):
    game = games.Othello()
    player1 = search.TreeSearchPlayer(depth, 'B', game.evaluation_function, alphabeta=alphabeta)
    player2 = search.RandomPlayer('W')

    state = game.start_state
    turn_player = player1

    while not game.is_terminal_state(state):
        action = turn_player.compute_action(game, state)
        if action is None:
            pass
        else:
            state = game.generate_next_state(state, action)
        turn_player = player2 if turn_player.player == player1.player else player1

    score1 = (state == player1.player).sum()
    score2 = (state == player2.player).sum()

    if len(logfile) > 0:
        with open(logfile, "a") as file:
            file.write("{}, {}, {}, {}\n".format(alphabeta, score1, score2, player1.expanded_nodes))


if __name__ == '__main__':
    for i in range(50):
        check_othello_performance(3, "alphabeta_vs_minmax.csv", alphabeta=False)
        check_othello_performance(3, "alphabeta_vs_minmax.csv", alphabeta=True)
